==> ejc-bidprice-api-3.0.0-20231030.092059-137-sources.jar: com/ejianc/business/bidprice/material/vo/PicketageQuotePurchaseDetailVO.java <==
package com.ejianc.business.bidprice.material.vo;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;


/**
 * 材料定标询价-报价记录-采购清单
 * 
 * @author generator
 * 
 */
public class PicketageQuotePurchaseDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long quoteId; // 报价单id
    private Long picketageQuoteId; // 定标 报价记录 主表id
    private Long sourceId; // 来源id
    private Long inquiryId; // 询价单id
    private Long materialCategoryId; // 物资分类Id
    private String materialCategoryName; // 物资分类名称
    private Long materialId; // 物资Id
    private String materialName; // 物资名称
    private String spec; // 规格型号
    private String unit; // 计量单位
    private BigDecimal residueNum; // 剩余采购数量
    private BigDecimal referPrice; // 参考价
    private BigDecimal bidNum; // 中标数量
    private BigDecimal bidPrice; // 中标单价
    private BigDecimal bidMny; // 中标金额
    private BigDecimal num; // 数量
    private Long picketageId; //主表id

    private BigDecimal bidPriceNoTax; // 中标单价
    private BigDecimal bidMnyNoTax; // 中标金额

    public BigDecimal getBidPriceNoTax() {
        return bidPriceNoTax;
    }

    public void setBidPriceNoTax(BigDecimal bidPriceNoTax) {
        this.bidPriceNoTax = bidPriceNoTax;
    }

    public BigDecimal getBidMnyNoTax() {
        return bidMnyNoTax;
    }

    public void setBidMnyNoTax(BigDecimal bidMnyNoTax) {
        this.bidMnyNoTax = bidMnyNoTax;
    }

    public Long getPicketageId() {
        return picketageId;
    }

    public void setPicketageId(Long picketageId) {
        this.picketageId = picketageId;
    }

    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }

    public Long getQuoteId() {
        return quoteId;
    }

    public void setQuoteId(Long quoteId) {
        this.quoteId = quoteId;
    }
    public Long getPicketageQuoteId() {
        return picketageQuoteId;
    }

    public void setPicketageQuoteId(Long picketageQuoteId) {
        this.picketageQuoteId = picketageQuoteId;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getInquiryId() {
        return inquiryId;
    }

    public void setInquiryId(Long inquiryId) {
        this.inquiryId = inquiryId;
    }
    public Long getMaterialCategoryId() {
        return materialCategoryId;
    }

    public void setMaterialCategoryId(Long materialCategoryId) {
        this.materialCategoryId = materialCategoryId;
    }
    public String getMaterialCategoryName() {
        return materialCategoryName;
    }

    public void setMaterialCategoryName(String materialCategoryName) {
        this.materialCategoryName = materialCategoryName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public BigDecimal getResidueNum() {
        return residueNum;
    }

    public void setResidueNum(BigDecimal residueNum) {
        this.residueNum = residueNum;
    }
    public BigDecimal getReferPrice() {
        return referPrice;
    }

    public void setReferPrice(BigDecimal referPrice) {
        this.referPrice = referPrice;
    }
    public BigDecimal getBidNum() {
        return bidNum;
    }

    public void setBidNum(BigDecimal bidNum) {
        this.bidNum = bidNum;
    }
    public BigDecimal getBidPrice() {
        return bidPrice;
    }

    public void setBidPrice(BigDecimal bidPrice) {
        this.bidPrice = bidPrice;
    }
    public BigDecimal getBidMny() {
        return bidMny;
    }

    public void setBidMny(BigDecimal bidMny) {
        this.bidMny = bidMny;
    }
    
}

==> ejc-bidprice-api-3.0.0-20241011.020225-160-sources.jar: com/ejianc/business/bidprice/material/vo/PicketageQuotePurchaseDetailVO.java <==
package com.ejianc.business.bidprice.material.vo;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;


/**
 * 材料定标询价-报价记录-采购清单
 * 
 * @author generator
 * 
 */
public class PicketageQuotePurchaseDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long quoteId; // 报价单id
    private Long picketageQuoteId; // 定标 报价记录 主表id
    private Long sourceId; // 来源id
    private Long inquiryId; // 询价单id
    private Long materialCategoryId; // 物资分类Id
    private String materialCategoryName; // 物资分类名称
    private Long materialId; // 物资Id
    private String materialName; // 物资名称
    private String spec; // 规格型号
    private String unit; // 计量单位
    private BigDecimal residueNum; // 剩余采购数量
    private BigDecimal referPrice; // 参考价
    private BigDecimal bidNum; // 中标数量
    private BigDecimal bidPrice; // 中标单价
    private BigDecimal bidMny; // 中标金额
    private BigDecimal num; // 数量
    private Long picketageId; //主表id

    private BigDecimal bidPriceNoTax; // 中标单价
    private BigDecimal bidMnyNoTax; // 中标金额

    private BigDecimal bidRate; // 中标税率

    public BigDecimal getBidRate() {
        return bidRate;
    }

    public void setBidRate(BigDecimal bidRate) {
        this.bidRate = bidRate;
    }


    public BigDecimal getBidPriceNoTax() {
        return bidPriceNoTax;
    }

    public void setBidPriceNoTax(BigDecimal bidPriceNoTax) {
        this.bidPriceNoTax = bidPriceNoTax;
    }

    public BigDecimal getBidMnyNoTax() {
        return bidMnyNoTax;
    }

    public void setBidMnyNoTax(BigDecimal bidMnyNoTax) {
        this.bidMnyNoTax = bidMnyNoTax;
    }

    public Long getPicketageId() {
        return picketageId;
    }

    public void setPicketageId(Long picketageId) {
        this.picketageId = picketageId;
    }

    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }

    public Long getQuoteId() {
        return quoteId;
    }

    public void setQuoteId(Long quoteId) {
        this.quoteId = quoteId;
    }
    public Long getPicketageQuoteId() {
        return picketageQuoteId;
    }

    public void setPicketageQuoteId(Long picketageQuoteId) {
        this.picketageQuoteId = picketageQuoteId;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getInquiryId() {
        return inquiryId;
    }

    public void setInquiryId(Long inquiryId) {
        this.inquiryId = inquiryId;
    }
    public Long getMaterialCategoryId() {
        return materialCategoryId;
    }

    public void setMaterialCategoryId(Long materialCategoryId) {
        this.materialCategoryId = materialCategoryId;
    }
    public String getMaterialCategoryName() {
        return materialCategoryName;
    }

    public void setMaterialCategoryName(String materialCategoryName) {
        this.materialCategoryName = materialCategoryName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public BigDecimal getResidueNum() {
        return residueNum;
    }

    public void setResidueNum(BigDecimal residueNum) {
        this.residueNum = residueNum;
    }
    public BigDecimal getReferPrice() {
        return referPrice;
    }

    public void setReferPrice(BigDecimal referPrice) {
        this.referPrice = referPrice;
    }
    public BigDecimal getBidNum() {
        return bidNum;
    }

    public void setBidNum(BigDecimal bidNum) {
        this.bidNum = bidNum;
    }
    public BigDecimal getBidPrice() {
        return bidPrice;
    }

    public void setBidPrice(BigDecimal bidPrice) {
        this.bidPrice = bidPrice;
    }
    public BigDecimal getBidMny() {
        return bidMny;
    }

    public void setBidMny(BigDecimal bidMny) {
        this.bidMny = bidMny;
    }
    
}
